# Artifact

!!! tip inline end "API Classes"
    Found a method here you want to use? The [API Classes](../../api_classes/overview.md) have method pass-through so just call the method on the any class that inherits from the **Artifact** Class and voilà it works the same.

The Workbench Artifact class is a base/abstract class that defines API implemented by all the child classes (DataSource, FeatureSet, Model, Endpoint).

::: workbench.core.artifacts.artifact
